**Example 1: 修改溯源信息的排序**



Input: 

```
tccli trp ModifyTraceDataRanks --cli-unfold-argument  \
    --BatchId xx \
    --TraceIds xx
```

Output: 
```
{
    "Response": {
        "BatchId": "xx",
        "RequestId": "xx"
    }
}
```

